Package io.microsphere.test.annotation
Annotation Type TestAnnotation
-
@Retention(RUNTIME) @Target(TYPE) @Documented public @interface TestAnnotationTheAnnotationfor testing- Since:
- 1.0.0
- Author:
- Mercy
- See Also:
Annotation
-
-
Required Element Summary
Required Elements Modifier and Type Required Element Description io.microsphere.annotation.Sincesince
-
Optional Element Summary
Optional Elements Modifier and Type Optional Element Description bytebcharcdoubledfloatfintilonglio.microsphere.annotation.ConfigurationProperty[]propertiesshortsjava.lang.Stringstringjava.util.concurrent.TimeUnittimeUnitjava.lang.Class<?>typejava.lang.Class<?>[]typesbooleanz
-